@@ -34,7 +34,7 @@ func ccrDecode(d *decode.D, _ any) any {
 	d.FieldU3("reserved = 0")
 	initalPreDelay := d.FieldBool("initial_presentation_delay_present")
 	if initalPreDelay {
-		d.FieldU4("initial_presentation_delay", scalar.ActualUAdd(1))
+		d.FieldU4("initial_presentation_delay", scalar.UintActualAdd(1))
 	} else {
 		d.FieldU4("reserved")
 	}
