@@ -28,7 +28,7 @@ func init() {
 	})
 }
 
-var rawHexReverse = scalar.Fn(func(s scalar.S) (scalar.S, error) {
+var rawHexReverse = scalar.BitBufFn(func(s scalar.BitBuf) (scalar.BitBuf, error) {
 	return scalar.RawSym(s, -1, func(b []byte) string {
 		decode.ReverseBytes(b)
 		return fmt.Sprintf("%x", b)
@@ -45,11 +45,11 @@ func decodeBitcoinBlock(d *decode.D, in interface{}) interface{} {
 		case 0xf9beb4d9,
 			0x0b110907,
 			0xfabfb5da:
-			d.FieldU32("magic", scalar.UToSymStr{
+			d.FieldU32("magic", scalar.UintMapSymStr{
 				0xf9beb4d9: "mainnet",
 				0x0b110907: "testnet3",
 				0xfabfb5da: "regtest",
-			}, scalar.ActualHex)
+			}, scalar.UintHex)
 			size = int64(d.FieldU32LE("size")) * 8
 		default:
 			d.Fatalf("unknown magic %x", magic)
@@ -60,12 +60,12 @@ func decodeBitcoinBlock(d *decode.D, in interface{}) interface{} {
 
 	d.FramedFn(size, func(d *decode.D) {
 		d.FieldStruct("header", func(d *decode.D) {
-			d.FieldU32("version", scalar.ActualHex)
+			d.FieldU32("version", scalar.UintHex)
 			d.FieldRawLen("previous_block_hash", 32*8, rawHexReverse)
 			d.FieldRawLen("merkle_root", 32*8, rawHexReverse)
-			d.FieldU32("time", scalar.DescriptionUnixTimeFn(scalar.S.TryActualU, time.RFC3339))
-			d.FieldU32("bits", scalar.ActualHex)
-			d.FieldU32("nonce", scalar.ActualHex)
+			d.FieldU32("time", scalar.UintActualUnixTime(time.RFC3339))
+			d.FieldU32("bits", scalar.UintHex)
+			d.FieldU32("nonce", scalar.UintHex)
 		})
 
 		// TODO: remove? support header only decode this way?
@@ -73,7 +73,7 @@ func decodeBitcoinBlock(d *decode.D, in interface{}) interface{} {
 			return
 		}
 
-		txCount := d.FieldUFn("tx_count", decodeVarInt)
+		txCount := d.FieldUintFn("tx_count", decodeVarInt)
 		d.FieldArray("transactions", func(d *decode.D) {
 			for i := uint64(0); i < txCount; i++ {
 				d.FieldFormat("transaction", bitcoinTranscationFormat, nil)
