@@ -33,7 +33,7 @@ func init() {
 		Functions: []string{"_todisplay"},
 	})
 	interp.RegisterFS(csvFS)
-	interp.RegisterFunc1("_tocsv", toCSV)
+	interp.RegisterFunc1("_to_csv", toCSV)
 }
 
 func decodeCSV(d *decode.D, in any) any {
@@ -64,7 +64,7 @@ func decodeCSV(d *decode.D, in any) any {
 		rvs = append(rvs, vs)
 	}
 
-	d.Value.V = &scalar.S{Actual: rvs}
+	d.Value.V = &scalar.Any{Actual: rvs}
 	d.Value.Range.Len = d.Len()
 
 	return nil
