@@ -26,18 +26,18 @@ const (
 	classIN = 1
 )
 
-var classNames = scalar.URangeToScalar{
-	{Range: [2]uint64{0x0000, 0x0000}, S: scalar.S{Sym: "reserved", Description: "Reserved"}},
-	{Range: [2]uint64{classIN, classIN}, S: scalar.S{Sym: "in", Description: "Internet"}},
-	{Range: [2]uint64{0x0002, 0x0002}, S: scalar.S{Sym: "unassigned", Description: "Unassigned"}},
-	{Range: [2]uint64{0x0003, 0x0003}, S: scalar.S{Sym: "chaos", Description: "Chaos"}},
-	{Range: [2]uint64{0x0004, 0x0004}, S: scalar.S{Sym: "hesiod", Description: "Hesiod"}},
-	{Range: [2]uint64{0x0005, 0x00fd}, S: scalar.S{Sym: "unassigned", Description: "Unassigned"}},
-	{Range: [2]uint64{0x00fe, 0x00fe}, S: scalar.S{Sym: "qclass_none", Description: "QCLASS NONE"}},
-	{Range: [2]uint64{0x00ff, 0x00ff}, S: scalar.S{Sym: "qclass_any", Description: "QCLASS ANY"}},
-	{Range: [2]uint64{0x0100, 0xfeff}, S: scalar.S{Sym: "unassigned", Description: "Unassigned"}},
-	{Range: [2]uint64{0xff00, 0xfffe}, S: scalar.S{Sym: "private", Description: "Reserved for Private Use"}},
-	{Range: [2]uint64{0xffff, 0xffff}, S: scalar.S{Sym: "reserved", Description: "Reserved"}},
+var classNames = scalar.UintRangeToScalar{
+	{Range: [2]uint64{0x0000, 0x0000}, S: scalar.Uint{Sym: "reserved", Description: "Reserved"}},
+	{Range: [2]uint64{classIN, classIN}, S: scalar.Uint{Sym: "in", Description: "Internet"}},
+	{Range: [2]uint64{0x0002, 0x0002}, S: scalar.Uint{Sym: "unassigned", Description: "Unassigned"}},
+	{Range: [2]uint64{0x0003, 0x0003}, S: scalar.Uint{Sym: "chaos", Description: "Chaos"}},
+	{Range: [2]uint64{0x0004, 0x0004}, S: scalar.Uint{Sym: "hesiod", Description: "Hesiod"}},
+	{Range: [2]uint64{0x0005, 0x00fd}, S: scalar.Uint{Sym: "unassigned", Description: "Unassigned"}},
+	{Range: [2]uint64{0x00fe, 0x00fe}, S: scalar.Uint{Sym: "qclass_none", Description: "QCLASS NONE"}},
+	{Range: [2]uint64{0x00ff, 0x00ff}, S: scalar.Uint{Sym: "qclass_any", Description: "QCLASS ANY"}},
+	{Range: [2]uint64{0x0100, 0xfeff}, S: scalar.Uint{Sym: "unassigned", Description: "Unassigned"}},
+	{Range: [2]uint64{0xff00, 0xfffe}, S: scalar.Uint{Sym: "private", Description: "Reserved for Private Use"}},
+	{Range: [2]uint64{0xffff, 0xffff}, S: scalar.Uint{Sym: "reserved", Description: "Reserved"}},
 }
 
 const (
@@ -50,7 +50,7 @@ const (
 	typeAAAA  = 28
 )
 
-var typeNames = scalar.UToSymStr{
+var typeNames = scalar.UintMapSymStr{
 	typeA:     "a",
 	typeAAAA:  "aaaa",
 	18:        "afsdb",
@@ -100,7 +100,7 @@ var typeNames = scalar.UToSymStr{
 	65:        "https",
 }
 
-var rcodeNames = scalar.UToScalar{
+var rcodeNames = scalar.UintMap{
 	0:  {Sym: "no_error", Description: "No error"},
 	1:  {Sym: "form_err", Description: "Format error"},
 	2:  {Sym: "serv_fail", Description: "Server failure"},
@@ -230,11 +230,11 @@ func dnsDecode(d *decode.D, hasLengthHeader bool) any {
 			d.FieldU16("length")
 		}
 		d.FieldU16("id")
-		d.FieldU1("qr", scalar.UToSymStr{
+		d.FieldU1("qr", scalar.UintMapSymStr{
 			0: "query",
 			1: "response",
 		})
-		d.FieldU4("opcode", scalar.UToSymStr{
+		d.FieldU4("opcode", scalar.UintMapSymStr{
 			0: "query",
 			1: "iquery",
 			2: "status",
