@@ -36,7 +36,7 @@ const (
 	BlockingStrategyVariable = 1
 )
 
-var BlockingStrategyNames = scalar.UToSymStr{
+var BlockingStrategyNames = scalar.UintMapSymStr{
 	BlockingStrategyFixed:    "fixed",
 	BlockingStrategyVariable: "variable",
 }
@@ -71,9 +71,9 @@ const (
 	ResidualCodingMethodRice2 = 0b01
 )
 
-var ResidualCodingMethodMap = scalar.UToScalar{
-	ResidualCodingMethodRice:  scalar.S{Sym: uint64(4), Description: "rice"},
-	ResidualCodingMethodRice2: scalar.S{Sym: uint64(5), Description: "rice2"},
+var ResidualCodingMethodMap = scalar.UintMap{
+	ResidualCodingMethodRice:  scalar.Uint{Sym: uint64(4), Description: "rice"},
+	ResidualCodingMethodRice2: scalar.Uint{Sym: uint64(5), Description: "rice2"},
 }
 
 // TODO: generic enough?
@@ -115,12 +115,12 @@ func frameDecode(d *decode.D, in any) any {
 
 	d.FieldStruct("header", func(d *decode.D) {
 		// <14> 11111111111110
-		d.FieldU14("sync", d.AssertU(0b11111111111110), scalar.ActualBin)
+		d.FieldU14("sync", d.UintAssert(0b11111111111110), scalar.UintBin)
 
 		// <1> Reserved
 		// 0 : mandatory value
 		// 1 : reserved for future use
-		d.FieldU1("reserved0", d.AssertU(0))
+		d.FieldU1("reserved0", d.UintAssert(0))
 
 		// <1> Blocking strategy:
 		// 0 : fixed-blocksize stream; frame header encodes the frame number
@@ -134,7 +134,7 @@ func frameDecode(d *decode.D, in any) any {
 		// 0110 : get 8 bit (blocksize-1) from end of header
 		// 0111 : get 16 bit (blocksize-1) from end of header
 		// 1000-1111 : 256 * (2^(n-8)) samples, i.e. 256/512/1024/2048/4096/8192/16384/32768
-		var blockSizeMap = scalar.UToScalar{
+		var blockSizeMap = scalar.UintMap{
 			0b0000: {Description: "reserved"},
 			0b0001: {Sym: uint64(192)},
 			0b0010: {Sym: uint64(576)},
@@ -152,9 +152,9 @@ func frameDecode(d *decode.D, in any) any {
 			0b1110: {Sym: uint64(16384)},
 			0b1111: {Sym: uint64(32768)},
 		}
-		blockSizeS := d.FieldScalarU4("block_size", blockSizeMap, scalar.ActualBin)
+		blockSizeS := d.FieldScalarU4("block_size", blockSizeMap, scalar.UintBin)
 		if blockSizeS.Sym != nil {
-			blockSize = int(blockSizeS.SymU())
+			blockSize = int(blockSizeS.SymUint())
 		}
 
 		// <4> Sample rate:
@@ -174,7 +174,7 @@ func frameDecode(d *decode.D, in any) any {
 		// 1101 : get 16 bit sample rate (in Hz) from end of header
 		// 1110 : get 16 bit sample rate (in tens of Hz) from end of header
 		// 1111 : invalid, to prevent sync-fooling string of 1s
-		var sampleRateMap = scalar.UToScalar{
+		var sampleRateMap = scalar.UintMap{
 			0b0000: {Description: "from streaminfo"},
 			0b0001: {Sym: uint64(88200)},
 			0b0010: {Sym: uint64(176400)},
@@ -192,7 +192,7 @@ func frameDecode(d *decode.D, in any) any {
 			0b1110: {Description: "end of header (16 bit*10)"},
 			0b1111: {Description: "invalid"},
 		}
-		sampleRateS := d.FieldScalarU4("sample_rate", sampleRateMap, scalar.ActualBin)
+		sampleRateS := d.FieldScalarU4("sample_rate", sampleRateMap, scalar.UintBin)
 
 		// <4> Channel assignment
 		// 0000-0111 : (number of independent channels)-1. Where defined, the channel order follows SMPTE/ITU-R recommendations. The assignments are as follows:
@@ -209,7 +209,7 @@ func frameDecode(d *decode.D, in any) any {
 		// 1010 : mid/side stereo: channel 0 is the mid(average) channel, channel 1 is the side(difference) channel
 		// 1011-1111 : reserved
 		// TODO: extract to tables and cleanup
-		var channelAssignmentMap = scalar.UToScalar{
+		var channelAssignmentMap = scalar.UintMap{
 			0:      {Sym: uint64(1), Description: "mono"},
 			1:      {Sym: uint64(2), Description: "lr"},
 			2:      {Sym: uint64(3), Description: "lrc"},
@@ -226,13 +226,13 @@ func frameDecode(d *decode.D, in any) any {
 			0b1101: {Sym: nil, Description: "reserved"},
 			0b1111: {Sym: nil, Description: "reserved"},
 		}
-		channelAssignmentS := d.FieldScalarU4("channel_assignment", channelAssignmentMap)
-		if channelAssignmentS.Sym == nil {
+		channelAssignmentUint := d.FieldScalarU4("channel_assignment", channelAssignmentMap)
+		if channelAssignmentUint.Sym == nil {
 			d.Fatalf("unknown number of channels")
 		}
-		channelAssignment = channelAssignmentS.ActualU()
-		channels = int(channelAssignmentS.SymU())
-		switch channelAssignmentS.ActualU() {
+		channelAssignment = channelAssignmentUint.Actual
+		channels = int(channelAssignmentUint.SymUint())
+		switch channelAssignmentUint.Actual {
 		case ChannelLeftSide:
 			sideChannelIndex = 1
 		case ChannelSideRight:
@@ -241,7 +241,7 @@ func frameDecode(d *decode.D, in any) any {
 			sideChannelIndex = 1
 		}
 		if sideChannelIndex != -1 {
-			d.FieldValueU("side_channel_index", uint64(sideChannelIndex))
+			d.FieldValueUint("side_channel_index", uint64(sideChannelIndex))
 		}
 
 		// <3> Sample size in bits:
@@ -253,7 +253,7 @@ func frameDecode(d *decode.D, in any) any {
 		// 101 : 20 bits per sample
 		// 110 : 24 bits per sample
 		// 111 : reserved
-		var sampleSizeMap = scalar.UToScalar{
+		var sampleSizeMap = scalar.UintMap{
 			0b000: {Description: "from streaminfo"},
 			0b001: {Sym: uint64(8)},
 			0b010: {Sym: uint64(12)},
@@ -263,20 +263,20 @@ func frameDecode(d *decode.D, in any) any {
 			0b110: {Sym: uint64(24)},
 			0b111: {Sym: uint64(32)},
 		}
-		sampleSizeS := d.FieldScalarU3("sample_size", sampleSizeMap, scalar.ActualBin)
-		switch sampleSizeS.ActualU() {
+		sampleSizeS := d.FieldScalarU3("sample_size", sampleSizeMap, scalar.UintBin)
+		switch sampleSizeS.Actual {
 		case SampleSizeStreaminfo:
 			sampleSize = ffi.BitsPerSample
 		default:
 			if sampleSizeS.Sym != nil {
-				sampleSize = int(sampleSizeS.SymU())
+				sampleSize = int(sampleSizeS.SymUint())
 			}
 		}
 
 		// <1> Reserved:
 		// 0 : mandatory value
 		// 1 : reserved for future use
-		d.FieldU1("reserved1", d.AssertU(0))
+		d.FieldU1("reserved1", d.UintAssert(0))
 
 		d.FieldStruct("end_of_header", func(d *decode.D) {
 			// if(variable blocksize)
@@ -287,20 +287,20 @@ func frameDecode(d *decode.D, in any) any {
 			// 1 : variable-blocksize stream; frame header encodes the sample number
 			switch blockingStrategy {
 			case BlockingStrategyVariable:
-				d.FieldUFn("sample_number", utf8Uint)
+				d.FieldUintFn("sample_number", utf8Uint)
 			case BlockingStrategyFixed:
-				d.FieldUFn("frame_number", utf8Uint)
+				d.FieldUintFn("frame_number", utf8Uint)
 			}
 
 			// if(blocksize bits == 011x)
 			//   8/16 bit (blocksize-1)
 			// 0110 : get 8 bit (blocksize-1) from end of header
 			// 0111 : get 16 bit (blocksize-1) from end of header
-			switch blockSizeS.ActualU() {
+			switch blockSizeS.Actual {
 			case BlockSizeEndOfHeader8:
-				blockSize = int(d.FieldU8("block_size", scalar.ActualUAdd(1)))
+				blockSize = int(d.FieldU8("block_size", scalar.UintActualAdd(1)))
 			case BlockSizeEndOfHeader16:
-				blockSize = int(d.FieldU16("block_size", scalar.ActualUAdd(1)))
+				blockSize = int(d.FieldU16("block_size", scalar.UintActualAdd(1)))
 			}
 
 			// if(sample rate bits == 11xx)
@@ -308,19 +308,19 @@ func frameDecode(d *decode.D, in any) any {
 			// 1100 : get 8 bit sample rate (in kHz) from end of header
 			// 1101 : get 16 bit sample rate (in Hz) from end of header
 			// 1110 : get 16 bit sample rate (in tens of Hz) from end of header
-			switch sampleRateS.ActualU() {
+			switch sampleRateS.Actual {
 			case SampeleRateEndOfHeader8:
-				d.FieldUFn("sample_rate", func(d *decode.D) uint64 { return d.U8() * 1000 })
+				d.FieldUintFn("sample_rate", func(d *decode.D) uint64 { return d.U8() * 1000 })
 			case SampeleRateEndOfHeader16:
 				d.FieldU16("sample_rate")
 			case SampeleRateEndOfHeader160:
-				d.FieldUFn("sample_rate", func(d *decode.D) uint64 { return d.U16() * 10 })
+				d.FieldUintFn("sample_rate", func(d *decode.D) uint64 { return d.U16() * 10 })
 			}
 		})
 
 		headerCRC := &checksum.CRC{Bits: 8, Table: checksum.ATM8Table}
 		d.CopyBits(headerCRC, d.BitBufRange(frameStart, d.Pos()-frameStart))
-		d.FieldU8("crc", d.ValidateUBytes(headerCRC.Sum(nil)), scalar.ActualHex)
+		d.FieldU8("crc", d.UintValidateBytes(headerCRC.Sum(nil)), scalar.UintHex)
 	})
 
 	var channelSamples [][]int64
@@ -328,7 +328,7 @@ func frameDecode(d *decode.D, in any) any {
 		for channelIndex := 0; channelIndex < channels; channelIndex++ {
 			d.FieldStruct("subframe", func(d *decode.D) {
 				// <1> Zero bit padding, to prevent sync-fooling string of 1s
-				d.FieldU1("zero_bit", d.AssertU(0))
+				d.FieldU1("zero_bit", d.UintAssert(0))
 
 				// <6> Subframe type:
 				// 000000 : SUBFRAME_CONSTANT
@@ -339,25 +339,25 @@ func frameDecode(d *decode.D, in any) any {
 				// 01xxxx : reserved
 				// 1xxxxx : SUBFRAME_LPC, xxxxx=order-1
 				lpcOrder := -1
-				var subframeTypeRangeMap = scalar.URangeToScalar{
-					{Range: [2]uint64{0b000000, 0b000000}, S: scalar.S{Sym: SubframeConstant}},
-					{Range: [2]uint64{0b000001, 0b000001}, S: scalar.S{Sym: SubframeVerbatim}},
-					{Range: [2]uint64{0b000010, 0b000011}, S: scalar.S{Sym: SubframeReserved}},
-					{Range: [2]uint64{0b000100, 0b000111}, S: scalar.S{Sym: SubframeReserved}},
-					{Range: [2]uint64{0b001000, 0b001100}, S: scalar.S{Sym: SubframeFixed}},
-					{Range: [2]uint64{0b001101, 0b001111}, S: scalar.S{Sym: SubframeReserved}},
-					{Range: [2]uint64{0b010000, 0b011111}, S: scalar.S{Sym: SubframeReserved}},
-					{Range: [2]uint64{0b100000, 0b111111}, S: scalar.S{Sym: SubframeLPC}},
+				var subframeTypeRangeMap = scalar.UintRangeToScalar{
+					{Range: [2]uint64{0b000000, 0b000000}, S: scalar.Uint{Sym: SubframeConstant}},
+					{Range: [2]uint64{0b000001, 0b000001}, S: scalar.Uint{Sym: SubframeVerbatim}},
+					{Range: [2]uint64{0b000010, 0b000011}, S: scalar.Uint{Sym: SubframeReserved}},
+					{Range: [2]uint64{0b000100, 0b000111}, S: scalar.Uint{Sym: SubframeReserved}},
+					{Range: [2]uint64{0b001000, 0b001100}, S: scalar.Uint{Sym: SubframeFixed}},
+					{Range: [2]uint64{0b001101, 0b001111}, S: scalar.Uint{Sym: SubframeReserved}},
+					{Range: [2]uint64{0b010000, 0b011111}, S: scalar.Uint{Sym: SubframeReserved}},
+					{Range: [2]uint64{0b100000, 0b111111}, S: scalar.Uint{Sym: SubframeLPC}},
 				}
-				subframeTypeS := d.FieldScalarU6("subframe_type", subframeTypeRangeMap, scalar.ActualBin)
-				switch subframeTypeS.SymStr() {
+				subframeTypeUint := d.FieldScalarU6("subframe_type", subframeTypeRangeMap, scalar.UintBin)
+				switch subframeTypeUint.SymStr() {
 				case SubframeFixed:
-					lpcOrder = int(subframeTypeS.ActualU() & 0b111)
+					lpcOrder = int(subframeTypeUint.Actual & 0b111)
 				case SubframeLPC:
-					lpcOrder = int((subframeTypeS.ActualU() & 0b11111) + 1)
+					lpcOrder = int((subframeTypeUint.Actual & 0b11111) + 1)
 				}
 				if lpcOrder != -1 {
-					d.FieldValueU("lpc_order", uint64(lpcOrder))
+					d.FieldValueUint("lpc_order", uint64(lpcOrder))
 				}
 
 				// 'Wasted bits-per-sample' flag:
@@ -366,7 +366,7 @@ func frameDecode(d *decode.D, in any) any {
 				wastedBitsFlag := d.FieldU1("wasted_bits_flag")
 				var wastedBitsK int
 				if wastedBitsFlag != 0 {
-					wastedBitsK = int(d.FieldUnary("wasted_bits_k", 0, scalar.ActualUAdd(1)))
+					wastedBitsK = int(d.FieldUnary("wasted_bits_k", 0, scalar.UintActualAdd(1)))
 				}
 
 				subframeSampleSize := sampleSize - wastedBitsK
@@ -378,7 +378,7 @@ func frameDecode(d *decode.D, in any) any {
 				if channelIndex == sideChannelIndex {
 					subframeSampleSize++
 				}
-				d.FieldValueU("subframe_sample_size", uint64(subframeSampleSize))
+				d.FieldValueUint("subframe_sample_size", uint64(subframeSampleSize))
 
 				decodeWarmupSamples := func(samples []int64, n int, sampleSize int) {
 					if len(samples) < n {
@@ -402,9 +402,9 @@ func frameDecode(d *decode.D, in any) any {
 					// 10-11 : reserved
 					var riceEscape int
 					var riceBits int
-					residualCodingMethod := d.FieldU2("residual_coding_method", scalar.UToScalar{
-						0b00: scalar.S{Sym: uint64(4), Description: "rice"},
-						0b01: scalar.S{Sym: uint64(5), Description: "rice2"},
+					residualCodingMethod := d.FieldU2("residual_coding_method", scalar.UintMap{
+						0b00: scalar.Uint{Sym: uint64(4), Description: "rice"},
+						0b01: scalar.Uint{Sym: uint64(5), Description: "rice2"},
 					})
 					switch residualCodingMethod {
 					case ResidualCodingMethodRice:
@@ -419,7 +419,7 @@ func frameDecode(d *decode.D, in any) any {
 					partitionOrder := int(d.FieldU4("partition_order"))
 					// There will be 2^order partitions.
 					ricePartitions := 1 << partitionOrder
-					d.FieldValueU("rice_partitions", uint64(ricePartitions))
+					d.FieldValueUint("rice_partitions", uint64(ricePartitions))
 
 					d.FieldArray("partitions", func(d *decode.D) {
 						for i := 0; i < ricePartitions; i++ {
@@ -445,7 +445,7 @@ func frameDecode(d *decode.D, in any) any {
 									count = (blockSize / ricePartitions) - lpcOrder
 								}
 
-								d.FieldValueU("count", uint64(count))
+								d.FieldValueUint("count", uint64(count))
 
 								riceParameter := int(d.FieldU("rice_parameter", riceBits))
 
@@ -504,7 +504,7 @@ func frameDecode(d *decode.D, in any) any {
 				}
 
 				samples := make([]int64, blockSize)
-				switch subframeTypeS.SymStr() {
+				switch subframeTypeUint.SymStr() {
 				case SubframeConstant:
 					// <n> Unencoded constant value of the subblock, n = frame's bits-per-sample.
 					v := d.FieldS("value", subframeSampleSize)
@@ -540,7 +540,7 @@ func frameDecode(d *decode.D, in any) any {
 					// <n> Unencoded warm-up samples (n = frame's bits-per-sample * lpc order).
 					decodeWarmupSamples(samples, lpcOrder, subframeSampleSize)
 					// <4> (Quantized linear predictor coefficients' precision in bits)-1 (1111 = invalid).
-					precision := int(d.FieldU4("precision", scalar.ActualUAdd(1)))
+					precision := int(d.FieldU4("precision", scalar.UintActualAdd(1)))
 					// <5> Quantized linear predictor coefficient shift needed in bits (NOTE: this number is signed two's-complement).
 					shift := d.FieldS5("shift")
 					if shift < 0 {
@@ -570,7 +570,7 @@ func frameDecode(d *decode.D, in any) any {
 	})
 
 	// <?> Zero-padding to byte alignment.
-	d.FieldU("byte_align", d.ByteAlignBits(), d.AssertU(0))
+	d.FieldU("byte_align", d.ByteAlignBits(), d.UintAssert(0))
 	// <16> CRC-16 (polynomial = x^16 + x^15 + x^2 + x^0, initialized with 0) of everything before the crc, back to and including the frame header sync code
 	footerCRC := &checksum.CRC{Bits: 16, Table: checksum.ANSI16Table}
 	d.CopyBits(footerCRC, d.BitBufRange(frameStart, d.Pos()-frameStart))
