@@ -27,9 +27,9 @@ func init() {
 }
 
 // TODO: move to shared?
-var mapUToEtherSym = scalar.Fn(func(s scalar.S) (scalar.S, error) {
+var mapUToEtherSym = scalar.UintFn(func(s scalar.Uint) (scalar.Uint, error) {
 	var b [8]byte
-	binary.BigEndian.PutUint64(b[:], s.ActualU())
+	binary.BigEndian.PutUint64(b[:], s.Actual)
 	s.Sym = fmt.Sprintf("%.2x:%.2x:%.2x:%.2x:%.2x:%.2x", b[2], b[3], b[4], b[5], b[6], b[7])
 	return s, nil
 })
@@ -41,9 +41,9 @@ func decodeEthernetFrame(d *decode.D, in any) any {
 		}
 	}
 
-	d.FieldU("destination", 48, mapUToEtherSym, scalar.ActualHex)
-	d.FieldU("source", 48, mapUToEtherSym, scalar.ActualHex)
-	etherType := d.FieldU16("ether_type", format.EtherTypeMap, scalar.ActualHex)
+	d.FieldU("destination", 48, mapUToEtherSym, scalar.UintHex)
+	d.FieldU("source", 48, mapUToEtherSym, scalar.UintHex)
+	etherType := d.FieldU16("ether_type", format.EtherTypeMap, scalar.UintHex)
 
 	d.FieldFormatOrRawLen(
 		"payload",
