@@ -31,7 +31,7 @@ func init() {
 		Functions:   []string{"_todisplay"},
 	})
 	interp.RegisterFS(jsonFS)
-	interp.RegisterFunc1("_tojson", toJSON)
+	interp.RegisterFunc1("_to_json", toJSON)
 }
 
 func decodeJSONEx(d *decode.D, lines bool) any {
@@ -66,7 +66,7 @@ func decodeJSONEx(d *decode.D, lines bool) any {
 		d.Fatalf("trialing data after top-level value")
 	}
 
-	var s scalar.S
+	var s scalar.Any
 	if lines {
 		if len(vs) == 0 {
 			d.Fatalf("not lines found")
