@@ -1,7 +1,5 @@
 package mp4
 
-// TODO: flags?
-
 import (
 	"bytes"
 	"encoding/binary"
@@ -361,8 +359,18 @@ func decodeBoxIrefEntry(ctx *decodeContext, d *decode.D) {
 }
 
 func decodeBoxFtyp(d *decode.D) {
-	d.FieldUTF8("major_brand", 4)
-	d.FieldU32("minor_version")
+	brand := d.FieldUTF8("major_brand", 4)
+	d.FieldU32("minor_version", scalar.UintFn(func(s scalar.Uint) (scalar.Uint, error) {
+		switch brand {
+		case "qt  ":
+			// https://developer.apple.com/library/archive/documentation/QuickTime/QTFF/QTFFChap1/qtff1.html#//apple_ref/doc/uid/TP40000939-CH203-BBCGDDDF
+			// "For QuickTime movie files, this takes the form of four binary-coded decimal values, indicating the century,
+			//  year, and month of the QuickTime File Format Specification, followed by a binary coded decimal zero. For example,
+			//  for the June 2004 minor version, this field is set to the BCD values 20 04 06 00."
+			s.Description = fmt.Sprintf("%.4d.%.2d", (s.Actual>>24)&0xff_ff, (s.Actual>>8)&0xff)
+		}
+		return s, nil
+	}))
 	numBrands := d.BitsLeft() / 8 / 4
 	var i int64
 	d.FieldArrayLoop("brands", func() bool { return i < numBrands }, func(d *decode.D) {
@@ -433,7 +441,13 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 	case "tkhd":
 		var trackID int
 		version := d.FieldU8("version")
-		d.FieldU24("flags")
+		d.FieldStruct("flags", func(d *decode.D) {
+			d.FieldU20("unused")
+			d.FieldBool("size_is_aspect_ratio")
+			d.FieldBool("in_preview")
+			d.FieldBool("in_movie")
+			d.FieldBool("enabled")
+		})
 		switch version {
 		case 0:
 			d.FieldU32("creation_time", uintActualQuicktimeEpoch)
@@ -1317,7 +1331,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 	case "sgpd":
 		version := d.FieldU8("version")
 		d.FieldU24("flags")
-		d.FieldU32("grouping_type")
+		d.FieldUTF8("grouping_type", 4)
 		var defaultLength uint64
 		if version == 1 {
 			defaultLength = d.FieldU32("default_length")
@@ -1345,7 +1359,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		version := d.FieldU8("version")
 		d.FieldU24("flags")
 
-		d.FieldU32("grouping_type")
+		d.FieldUTF8("grouping_type", 4)
 		if version == 1 {
 			d.FieldU32("grouping_type_parameter")
 		}
@@ -1633,9 +1647,55 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 			}
 		})
 	default:
+		// there are at least 4 ways to encode udta metadata in mov/mp4 files.
+		//
+		// mdta subtype:
+		//
+		// udta:
+		//   meta
+		//     hdlr with subtype "mdta"
+		//     keys with 1-based <index> to key namespace.name table
+		//     ilst
+		//       <index>-box (box type is 32bit BE 1-based number into table above)
+		//         data box with value
+		//
+		// mdir subtype:
+		//
+		// udta
+		//   meta
+		//     hdlr with subtype "mdir"
+		//     ilst
+		//       ©<abc> or similar
+		//         data with value
+		//
+		// no-meta-box with length and language:
+		//
+		// udta
+		//   ©<abc> or similar
+		//     value length and language
+		//
+		// no-meta-box value rest of box:
+		//
+		// udta
+		//   <name>
+		//     value rest of box
 		if mb := ctx.currentMetaBox(); mb != nil && ctx.parent().typ == "ilst" {
-			// unknown type inside a metadata box with ilst as parent, decode item boxes
+			// unknown type under a meta box with ilst as parent, decode as boxes
+			// is probably one or more data boxes
 			decodeBoxes(ctx, d)
+		} else if ctx.parent().typ == "udta" {
+			// TODO: better probe? ffmpeg uses box name heuristics?
+			// if 16 length field seems to match assume box with length, language and value
+			// otherwise decode as box with value rest of box
+			probeLength := d.PeekBits(16)
+			// +2 for length field, +2 for language field
+			if (probeLength+2+2)*8 == uint64(d.BitsLeft()) {
+				length := d.FieldU16("length")
+				d.FieldStrFn("language", decodeLang)
+				d.FieldUTF8("value", int(length))
+			} else {
+				d.FieldUTF8("value", int(d.BitsLeft()/8))
+			}
 		} else {
 			d.FieldRawLen("data", d.BitsLeft())
 		}
