@@ -24,7 +24,7 @@ func init() {
 
 func widevineDecode(d *decode.D, _ any) any {
 	widewinePb := format.ProtoBufMessage{
-		1: {Type: format.ProtoBufTypeEnum, Name: "algorithm", Enums: scalar.UToSymStr{
+		1: {Type: format.ProtoBufTypeEnum, Name: "algorithm", Enums: scalar.UintMapSymStr{
 			0: "unencrypted",
 			1: "aesctr",
 		}},
@@ -34,7 +34,7 @@ func widevineDecode(d *decode.D, _ any) any {
 		6: {Type: format.ProtoBufTypeString, Name: "policy"},
 		7: {Type: format.ProtoBufTypeUInt32, Name: "crypto_period_index"},
 		8: {Type: format.ProtoBufTypeBytes, Name: "grouped_license"},
-		9: {Type: format.ProtoBufTypeUInt32, Name: "protection_scheme", Enums: scalar.UToSymStr{
+		9: {Type: format.ProtoBufTypeUInt32, Name: "protection_scheme", Enums: scalar.UintMapSymStr{
 			1667591779: "cenc",
 			1667392305: "cbc1",
 			1667591795: "cens",
