@@ -365,7 +365,7 @@ const (
 	PaletteHistogram = 0x5113
 )
 
-var tiffTagNames = scalar.UToSymStr{
+var tiffTagNames = scalar.UintMapSymStr{
 	NewSubfileType:               "NewSubfileType",
 	SubfileType:                  "SubfileType",
 	ImageWidth:                   "ImageWidth",
@@ -761,7 +761,7 @@ const (
 	GPSHPositioningError = 0x001f
 )
 
-var gpsInfoTagNames = scalar.UToSymStr{
+var gpsInfoTagNames = scalar.UintMapSymStr{
 	GPSVersionID:         "GPSVersionID",
 	GPSLatitudeRef:       "GPSLatitudeRef",
 	GPSLatitude:          "GPSLatitude",
