@@ -26,7 +26,7 @@ func init() {
 		Functions:   []string{"_todisplay"},
 	})
 	interp.RegisterFS(tomlFS)
-	interp.RegisterFunc0("totoml", toTOML)
+	interp.RegisterFunc0("to_toml", toTOML)
 }
 
 func decodeTOML(d *decode.D, _ any) any {
@@ -36,7 +36,7 @@ func decodeTOML(d *decode.D, _ any) any {
 	if _, err := toml.NewDecoder(bitio.NewIOReader(br)).Decode(&r); err != nil {
 		d.Fatalf("%s", err)
 	}
-	var s scalar.S
+	var s scalar.Any
 	s.Actual = gojqex.Normalize(r)
 
 	// TODO: better way to handle that an empty file is valid toml and parsed as an object
@@ -58,7 +58,7 @@ func decodeTOML(d *decode.D, _ any) any {
 
 func toTOML(_ *interp.Interp, c any) any {
 	if c == nil {
-		return gojqex.FuncTypeError{Name: "totoml", V: c}
+		return gojqex.FuncTypeError{Name: "to_toml", V: c}
 	}
 
 	b := &bytes.Buffer{}
