@@ -212,7 +212,7 @@ func decodeHTML(d *decode.D, in any) any {
 	if err != nil {
 		d.Fatalf("%s", err)
 	}
-	var s scalar.S
+	var s scalar.Any
 	s.Actual = r
 
 	d.Value.V = &s
