@@ -54,7 +54,7 @@ const (
 	compressionMethodPPMd                      = 98
 )
 
-var compressionMethodMap = scalar.UToSymStr{
+var compressionMethodMap = scalar.UintMapSymStr{
 	compressionMethodNone:                      "none",
 	compressionMethodShrunk:                    "shrunk",
 	compressionMethodReducedCompressionFactor1: "reduced_compression_factor1",
@@ -87,7 +87,7 @@ const (
 	headerIDZip64ExtendedInformation = 0x001
 )
 
-var headerIDMap = scalar.UToDescription{
+var headerIDMap = scalar.UintMapDescription{
 	headerIDZip64ExtendedInformation: "ZIP64 extended information extra field",
 	0x0007:                           "AV Info",
 	0x0009:                           "OS/2 extended attributes",
@@ -209,7 +209,7 @@ func zipDecode(d *decode.D, in any) any {
 			d.FramedFn(int64(sizeEOCD-sizeOfFixedFields)*8, func(d *decode.D) {
 				for !d.End() {
 					d.FieldStruct("extra_field", func(d *decode.D) {
-						d.FieldU16("header_id", headerIDMap, scalar.ActualHex)
+						d.FieldU16("header_id", headerIDMap, scalar.UintHex)
 						dataSize := d.FieldU32("data_size")
 						d.FieldRawLen("data", int64(dataSize)*8)
 					})
@@ -248,7 +248,7 @@ func zipDecode(d *decode.D, in any) any {
 					d.FieldU16("compression_method", compressionMethodMap)
 					d.FieldStruct("last_modification_date", fieldMSDOSTime)
 					d.FieldStruct("last_modification_time", fieldMSDOSDate)
-					d.FieldU32("crc32_uncompressed", scalar.ActualHex)
+					d.FieldU32("crc32_uncompressed", scalar.UintHex)
 					d.FieldU32("compressed_size")
 					d.FieldU32("uncompressed_size")
 					fileNameLength := d.FieldU16("file_name_length")
@@ -263,7 +263,7 @@ func zipDecode(d *decode.D, in any) any {
 						d.FramedFn(int64(extraFieldLength)*8, func(d *decode.D) {
 							for !d.End() {
 								d.FieldStruct("extra_field", func(d *decode.D) {
-									headerID := d.FieldU16("header_id", headerIDMap, scalar.ActualHex)
+									headerID := d.FieldU16("header_id", headerIDMap, scalar.UintHex)
 									dataSize := d.FieldU16("data_size")
 									d.FramedFn(int64(dataSize)*8, func(d *decode.D) {
 										switch headerID {
@@ -324,7 +324,7 @@ func zipDecode(d *decode.D, in any) any {
 				compressionMethod := d.FieldU16("compression_method", compressionMethodMap)
 				d.FieldStruct("last_modification_date", fieldMSDOSTime)
 				d.FieldStruct("last_modification_time", fieldMSDOSDate)
-				d.FieldU32("crc32_uncompressed", scalar.ActualHex)
+				d.FieldU32("crc32_uncompressed", scalar.UintHex)
 				compressedSizeBytes := d.FieldU32("compressed_size")
 				d.FieldU32("uncompressed_size")
 				fileNameLength := d.FieldU16("file_name_length")
@@ -334,7 +334,7 @@ func zipDecode(d *decode.D, in any) any {
 					d.FramedFn(int64(extraFieldLength)*8, func(d *decode.D) {
 						for !d.End() {
 							d.FieldStruct("extra_field", func(d *decode.D) {
-								headerID := d.FieldU16("header_id", headerIDMap, scalar.ActualHex)
+								headerID := d.FieldU16("header_id", headerIDMap, scalar.UintHex)
 								dataSize := d.FieldU16("data_size")
 								d.FramedFn(int64(dataSize)*8, func(d *decode.D) {
 									switch headerID {
@@ -397,7 +397,7 @@ func zipDecode(d *decode.D, in any) any {
 						if bytes.Equal(d.PeekBytes(4), dataIndicatorSignature) {
 							d.FieldRawLen("signature", 4*8, d.AssertBitBuf(dataIndicatorSignature))
 						}
-						d.FieldU32("crc32_uncompressed", scalar.ActualHex)
+						d.FieldU32("crc32_uncompressed", scalar.UintHex)
 						d.FieldU32("compressed_size")
 						d.FieldU32("uncompressed_size")
 					})
