@@ -1,8 +1,8 @@
-// This is gojq:s cli/encoder.go extract to be reusable and non-global color config
+// Package colorjson is gojq:s cli/encoder.go extract to be reusable and have non-global color config
 // TODO: possible gojq can export it?
 //
 // The MIT License (MIT)
-// Copyright (c) 2019-2021 itchyny
+// Copyright (c) 2019-2022 itchyny
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -21,15 +21,10 @@
 // LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-//
-
-// skip errcheck to keep code similar to gojq version
-//
-//nolint:errcheck
 package colorjson
 
 import (
-	"bufio"
+	"bytes"
 	"fmt"
 	"io"
 	"math"
@@ -52,13 +47,14 @@ type Colors struct {
 }
 
 type Encoder struct {
-	w       *bufio.Writer
-	wErr    error
+	out    io.Writer
+	w      *bytes.Buffer
+	tab    bool
+	indent int
+	depth  int
+	buf    [64]byte
+
 	color   bool
-	tab     bool
-	indent  int
-	depth   int
-	buf     [64]byte
 	valueFn func(v any) any
 	colors  Colors
 }
@@ -66,6 +62,7 @@ type Encoder struct {
 func NewEncoder(color bool, tab bool, indent int, valueFn func(v any) any, colors Colors) *Encoder {
 	// reuse the buffer in multiple calls of marshal
 	return &Encoder{
+		w:       new(bytes.Buffer),
 		color:   color,
 		tab:     tab,
 		indent:  indent,
@@ -74,16 +71,22 @@ func NewEncoder(color bool, tab bool, indent int, valueFn func(v any) any, color
 	}
 }
 
-func (e *Encoder) Marshal(v any, w io.Writer) error {
-	e.w = bufio.NewWriter(w)
-	e.encode(v)
-	if e.wErr != nil {
-		return e.wErr
-	}
-	return e.w.Flush()
+func (e *Encoder) flush() error {
+	_, err := e.out.Write(e.w.Bytes())
+	e.w.Reset()
+	return err
 }
 
-func (e *Encoder) encode(v any) {
+func (e *Encoder) Marshal(v interface{}, w io.Writer) error {
+	e.out = w
+	err := e.encode(v)
+	if ferr := e.flush(); ferr != nil && err == nil {
+		err = ferr
+	}
+	return err
+}
+
+func (e *Encoder) encode(v interface{}) error {
 	switch v := v.(type) {
 	case nil:
 		e.write([]byte("null"), e.colors.Null)
@@ -101,18 +104,26 @@ func (e *Encoder) encode(v any) {
 		e.write(v.Append(e.buf[:0], 10), e.colors.Number)
 	case string:
 		e.encodeString(v, e.colors.String)
-	case []any:
-		e.encodeArray(v)
-	case map[string]any:
-		e.encodeMap(v)
+	case []interface{}:
+		if err := e.encodeArray(v); err != nil {
+			return err
+		}
+	case map[string]interface{}:
+		if err := e.encodeMap(v); err != nil {
+			return err
+		}
 	default:
 		if e.valueFn != nil {
 			v = e.valueFn(v)
 		} else {
-			panic(fmt.Sprintf("invalid value: %#+v", v))
+			panic(fmt.Sprintf("invalid type: %[1]T (%[1]v)", v))
 		}
-		e.encode(v)
+		return e.encode(v)
 	}
+	if e.w.Len() > 8*1024 {
+		return e.flush()
+	}
+	return nil
 }
 
 // ref: floatEncoder in encoding/json
@@ -143,37 +154,38 @@ func (e *Encoder) encodeFloat64(f float64) {
 
 // ref: encodeState#string in encoding/json
 func (e *Encoder) encodeString(s string, color []byte) {
-	if e.color {
-		e.w.Write(color)
+	if color != nil {
+		e.setColor(e.w, color)
 	}
 	e.w.WriteByte('"')
 	start := 0
 	for i := 0; i < len(s); {
 		if b := s[i]; b < utf8.RuneSelf {
-			if ']' <= b && b <= '~' || '#' <= b && b <= '[' || b == ' ' || b == '!' {
+			if ' ' <= b && b <= '~' && b != '"' && b != '\\' {
 				i++
 				continue
 			}
 			if start < i {
 				e.w.WriteString(s[start:i])
 			}
-			e.w.WriteByte('\\')
 			switch b {
-			case '\\', '"':
-				e.w.WriteByte(b)
+			case '"':
+				e.w.WriteString(`\"`)
+			case '\\':
+				e.w.WriteString(`\\`)
 			case '\b':
-				e.w.WriteByte('b')
+				e.w.WriteString(`\b`)
 			case '\f':
-				e.w.WriteByte('f')
+				e.w.WriteString(`\f`)
 			case '\n':
-				e.w.WriteByte('n')
+				e.w.WriteString(`\n`)
 			case '\r':
-				e.w.WriteByte('r')
+				e.w.WriteString(`\r`)
 			case '\t':
-				e.w.WriteByte('t')
+				e.w.WriteString(`\t`)
 			default:
 				const hex = "0123456789abcdef"
-				e.w.WriteString("u00")
+				e.w.WriteString(`\u00`)
 				e.w.WriteByte(hex[b>>4])
 				e.w.WriteByte(hex[b&0xF])
 			}
@@ -197,40 +209,39 @@ func (e *Encoder) encodeString(s string, color []byte) {
 		e.w.WriteString(s[start:])
 	}
 	e.w.WriteByte('"')
-	if e.color {
-		e.w.Write(e.colors.Reset)
+	if color != nil {
+		e.setColor(e.w, e.colors.Reset)
 	}
 }
 
-func (e *Encoder) encodeArray(vs []any) {
+func (e *Encoder) encodeArray(vs []interface{}) error {
 	e.writeByte('[', e.colors.Array)
 	e.depth += e.indent
 	for i, v := range vs {
-		if e.wErr != nil {
-			return
-		}
-
 		if i > 0 {
 			e.writeByte(',', e.colors.Array)
 		}
 		if e.indent != 0 {
 			e.writeIndent()
 		}
-		e.encode(v)
+		if err := e.encode(v); err != nil {
+			return err
+		}
 	}
 	e.depth -= e.indent
 	if len(vs) > 0 && e.indent != 0 {
 		e.writeIndent()
 	}
 	e.writeByte(']', e.colors.Array)
+	return nil
 }
 
-func (e *Encoder) encodeMap(vs map[string]any) {
+func (e *Encoder) encodeMap(vs map[string]interface{}) error {
 	e.writeByte('{', e.colors.Object)
 	e.depth += e.indent
 	type keyVal struct {
 		key string
-		val any
+		val interface{}
 	}
 	kvs := make([]keyVal, len(vs))
 	var i int
@@ -242,10 +253,6 @@ func (e *Encoder) encodeMap(vs map[string]any) {
 		return kvs[i].key < kvs[j].key
 	})
 	for i, kv := range kvs {
-		if e.wErr != nil {
-			return
-		}
-
 		if i > 0 {
 			e.writeByte(',', e.colors.Object)
 		}
@@ -257,82 +264,65 @@ func (e *Encoder) encodeMap(vs map[string]any) {
 		if e.indent != 0 {
 			e.w.WriteByte(' ')
 		}
-		e.encode(kv.val)
+		if err := e.encode(kv.val); err != nil {
+			return err
+		}
 	}
 	e.depth -= e.indent
 	if len(vs) > 0 && e.indent != 0 {
 		e.writeIndent()
 	}
 	e.writeByte('}', e.colors.Object)
+	return nil
 }
 
 func (e *Encoder) writeIndent() {
 	e.w.WriteByte('\n')
 	if n := e.depth; n > 0 {
 		if e.tab {
-			const tabs = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t"
-			for n > len(tabs) {
-				e.w.Write([]byte(tabs))
-				n -= len(tabs)
-			}
-			e.w.Write([]byte(tabs)[:n])
+			e.writeIndentInternal(n, "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t")
 		} else {
-			const spaces = "                                                                "
-			for n > len(spaces) {
-				e.w.Write([]byte(spaces))
-				n -= len(spaces)
+			e.writeIndentInternal(n, "                                ")
+		}
+	}
+}
+
+func (e *Encoder) writeIndentInternal(n int, spaces string) {
+	if l := len(spaces); n <= l {
+		e.w.WriteString(spaces[:n])
+	} else {
+		e.w.WriteString(spaces)
+		for n -= l; n > 0; n, l = n-l, l*2 {
+			if n < l {
+				l = n
 			}
-			e.w.Write([]byte(spaces)[:n])
+			e.w.Write(e.w.Bytes()[e.w.Len()-l:])
 		}
 	}
 }
 
 func (e *Encoder) writeByte(b byte, color []byte) {
-	if e.wErr != nil {
-		return
-	}
 	if color == nil {
-		if err := e.w.WriteByte(b); err != nil {
-			e.wErr = err
-		}
+		e.w.WriteByte(b)
 	} else {
-		if e.color {
-			if _, err := e.w.Write(color); err != nil {
-				e.wErr = err
-			}
-		}
-		if err := e.w.WriteByte(b); err != nil {
-			e.wErr = err
-		}
-		if e.color {
-			if _, err := e.w.Write(e.colors.Reset); err != nil {
-				e.wErr = err
-			}
-		}
+		e.setColor(e.w, color)
+		e.w.WriteByte(b)
+		e.setColor(e.w, e.colors.Reset)
 	}
 }
 
 func (e *Encoder) write(bs []byte, color []byte) {
-	if e.wErr != nil {
-		return
-	}
 	if color == nil {
-		if _, err := e.w.Write(bs); err != nil {
-			e.wErr = err
-		}
+		e.w.Write(bs)
 	} else {
-		if e.color {
-			if _, err := e.w.Write(color); err != nil {
-				e.wErr = err
-			}
-		}
-		if _, err := e.w.Write(bs); err != nil {
-			e.wErr = err
-		}
-		if e.color {
-			if _, err := e.w.Write(e.colors.Reset); err != nil {
-				e.wErr = err
-			}
-		}
+		e.setColor(e.w, color)
+		e.w.Write(bs)
+		e.setColor(e.w, e.colors.Reset)
+	}
+}
+
+func (e *Encoder) setColor(buf *bytes.Buffer, color []byte) {
+	if e.color {
+		buf.Write(color)
 	}
 }
